@@ -24,9 +24,9 @@ names.rd_file <- function(x) {
 format.rd_file <- function(x, ...) {
   tags <- as.list(x[[1]])
   order <- c("docType", "encoding", "name", "alias", "title", "format",
-    "source", "usage", "arguments", "value", "description", "details", "slot", 
-    "note", "section", "examples", "author", "references", "seealso", "concept",
-    "keyword")
+    "source", "usage", "arguments", "value", "description", 
+    "details", "slot", "rcmethods", "note", "section", "examples", 
+    "author", "references", "seealso", "concept", "keyword")
 
   tags <- tags[intersect(order, names(tags))]
 
