@@ -1,19 +1,20 @@
-register.preref.parsers(parse.value, "template") 
+register.preref.parsers(parse.value, "template")
 register.preref.parsers(parse.name.description, "templateVar")
 
 template_find <- function(base_path, template_name) {
-  path <- file.path(base_path, "man-roxygen", str_c(template_name, ".R"))
+  path <- file.path(base_path, "man-roxygen", str_c(template_name, ".", c("R", "r")))
+  path_exists <- file.exists(path)
 
-  if (!file.exists(path)) {
+  if (!any(path_exists)) {
     stop("Can not find template ", template_name, call. = FALSE)
-  } 
-  
-  path
+  }
+
+  path[path_exists][1]
 }
 
 #' @importFrom brew brew
 template_eval <- function(template_path, vars) {
-  capture.output(brew(template_path, env = vars))
+  capture.output(brew(template_path, envir = vars))
 }
 
 process_templates <- function(partitum, base_path) {
@@ -22,19 +23,20 @@ process_templates <- function(partitum, base_path) {
   if (length(template_tags) == 0) return(partitum)
 
   templates <- unlist(template_tags, use.names = FALSE)
-  paths <- vapply(templates, template_find, base_path = base_path, 
+  paths <- vapply(templates, template_find, base_path = base_path,
     FUN.VALUE = character(1), USE.NAMES = FALSE)
-  
+
   var_tags <- partitum[names(partitum) == "templateVar"]
   vars <- lapply(var_tags, "[[", "description")
+  names(vars) <- vapply(var_tags, "[[", "name", FUN.VALUE = character(1))
   vars <- lapply(vars, type.convert, as.is = TRUE)
-  
+
   results <- lapply(paths, template_eval, vars = list2env(vars))
   
   # Insert templates back in the location where they came from
   partitum_pieces <- lapply(partitum, list)
   partitum_pieces[template_locs] <- lapply(results, parse.preref)
   names(partitum_pieces)[template_locs] <- ""
-  
+
   unlist(partitum_pieces, recursive = FALSE)
 }
